/*
** 1998-09-25 -	Include headers for all built-in commands. In alphabetical
**		order, for tidiness.
*/

#include "cmd_about.h"
#include "cmd_activate.h"
#include "cmd_chmod.h"
#include "cmd_chown.h"
#include "cmd_configure.h"
#include "cmd_copy.h"
#include "cmd_copyas.h"
#include "cmd_delete.h"
#include "cmd_direnter.h"
#include "cmd_dirrescan.h"
#include "cmd_dpfocus.h"
#include "cmd_dpmisc.h"
#include "cmd_file.h"
#include "cmd_getsize.h"
#include "cmd_info.h"
#include "cmd_join.h"
#include "cmd_menupopup.h"
#include "cmd_mkdir.h"
#include "cmd_move.h"
#include "cmd_moveas.h"
#include "cmd_parent.h"
#include "cmd_quit.h"
#include "cmd_rename.h"
#include "cmd_renamere.h"
#include "cmd_renameseq.h"
#include "cmd_run.h"
#include "cmd_select.h"
#include "cmd_split.h"
#include "cmd_swap.h"
#include "cmd_symlink.h"
#include "cmd_viewtext.h"
